@@ -1,8 +1,11 @@
 
-from breathe.renderer.rst.doxygen import format_parser_error
-from breathe.directive.base import BaseDirective
-from breathe.project import ProjectError
-from breathe.parser import ParserError, FileIOError
+from ..renderer.rst.doxygen.base import RenderContext
+from ..renderer.rst.doxygen.mask import NullMaskFactory
+from ..renderer.rst.doxygen import format_parser_error
+from ..directive.base import BaseDirective
+from ..project import ProjectError
+from ..parser import ParserError, FileIOError
+from .base import WarningHandler, create_warning
 
 from docutils.parsers.rst.directives import unchanged_required, flag
 from docutils import nodes
@@ -45,7 +48,10 @@ class BaseIndexDirective(BaseDirective):
             filter_,
             target_handler,
             )
-        object_renderer = renderer_factory.create_renderer(self.root_data_object, data_object)
+
+        mask_factory = NullMaskFactory()
+        context = RenderContext([data_object, self.root_data_object], mask_factory)
+        object_renderer = renderer_factory.create_renderer(context)
 
         try:
             node_list = object_renderer.render()
@@ -76,9 +82,8 @@ class DoxygenIndexDirective(BaseIndexDirective):
         try:
             project_info = self.project_info_factory.create_project_info(self.options)
         except ProjectError, e:
-            warning = 'doxygenindex: %s' % e
-            return [nodes.warning("", nodes.paragraph("", "", nodes.Text(warning))),
-                    self.state.document.reporter.warning(warning, line=self.lineno)]
+            warning = create_warning(None, self.state, self.lineno)
+            return warning.warn('doxygenindex: %s' % e)
 
         return self.handle_contents(project_info)
 
@@ -102,9 +107,8 @@ class AutoDoxygenIndexDirective(BaseIndexDirective):
         try:
             project_info = self.project_info_factory.retrieve_project_info_for_auto(self.options)
         except ProjectError, e:
-            warning = 'autodoxygenindex: %s' % e
-            return [nodes.warning("", nodes.paragraph("", "", nodes.Text(warning))),
-                    self.state.document.reporter.warning(warning, line=self.lineno)]
+            warning = create_warning(None, self.state, self.lineno)
+            return warning.warn('autodoxygenindex: %s' % e)
 
         return self.handle_contents(project_info)
 
