@@ -191,13 +191,15 @@ class DoxygenFunctionDirective(BaseDirective):
 
     def parse_args(self, function_description):
         # Strip off trailing qualifiers
-        function_description = re.sub(r'''(?<= \)) \s*
-                                          (?: const)? \s*
-                                          (?: volatile)? \s*
-                                          (?: = \s* 0)? \s* $ ''',
+        pattern = re.compile(r'''(?<= \)) \s*
+                                 (?: const)? \s*
+                                 (?: volatile)? \s*
+                                 (?: = \s* 0)? \s* $ ''',
+                                 re.VERBOSE)
+
+        function_description = re.sub(pattern,
                                       '',
-                                      function_description,
-                                      flags=re.VERBOSE)
+                                      function_description)
 
         paren_index = function_description.find('(')
         if paren_index == -1:
@@ -245,7 +247,7 @@ class DoxygenFunctionDirective(BaseDirective):
             target_handler = self.target_handler_factory.create_target_handler(
                 {'no-link': u''}, project_info, self.state.document
                 )
-            filter_ = self.filter_factory.create_outline_filter({'outline', ''})
+            filter_ = self.filter_factory.create_outline_filter({'outline': ''})
             mask_factory = MaskFactory({'param': NoParameterNamesMask})
             nodes = self.render(entry, project_info, filter_, target_handler, mask_factory)
 
@@ -273,7 +275,8 @@ class DoxygenFunctionDirective(BaseDirective):
 class DoxygenClassLikeDirective(BaseDirective):
 
     required_arguments = 1
-    optional_arguments = 1
+    optional_arguments = 0
+    final_argument_whitespace = True
     option_spec = {
         "path": unchanged_required,
         "project": unchanged_required,
@@ -482,7 +485,7 @@ class DoxygenBaseItemDirective(BaseDirective):
         except NoMatchesError as e:
             display_name = "%s::%s" % (namespace, name) if namespace else name
             warning = create_warning(project_info, self.state, self.lineno, kind=self.kind,
-                                     name=display_name)
+                                     display_name=display_name)
             return warning.warn('doxygen{kind}: Cannot find {kind} "{display_name}" {tail}')
 
         target_handler = self.target_handler_factory.create_target_handler(
