@@ -21,7 +21,7 @@ class CompoundDefTypeSubRenderer(Renderer):
                 ("public-type", "Public Type"),
                 ("public-func", "Public Functions"),
                 ("public-attrib", "Public Members"),
-                ("public-slot", "Public Slot"),
+                ("public-slot", "Public Slots"),
                 ("signal", "Signal"),
                 ("dcop-func",  "DCOP Function"),
                 ("property",  "Property"),
@@ -449,9 +449,11 @@ class ParamTypeSubRenderer(Renderer):
             if nodelist: nodelist.append(self.node_factory.Text(" "))
             nodelist.append(self.node_factory.emphasis(text=self.data_object.declname))
 
-        if self.output_defname and self.data_object.defname:
+        elif self.output_defname and self.data_object.defname:
+            # We only want to output the definition name (from the cpp file) if the declaration name
+            # (from header file) isn't present
             if nodelist: nodelist.append(self.node_factory.Text(" "))
-            nodelist.append(self.node_factory.Text(self.data_object.defname))
+            nodelist.append(self.node_factory.emphasis(text=self.data_object.defname))
 
         # Default value
         if self.data_object.defval:
@@ -907,19 +909,17 @@ class VerbatimTypeSubRenderer(Renderer):
 class MixedContainerRenderer(Renderer):
 
     def render(self):
-
         context = self.context.create_child_context(self.data_object.getValue())
         renderer = self.renderer_factory.create_renderer(context)
         return renderer.render()
 
 
 class DocListNestedRenderer(object):
-    """
-        Decorator for the list type renderer.
+    """Decorator for the list type renderer.
 
-        Creates the proper docutils node based on the sub-type
-        of the underlying data object. Takes care of proper numbering
-        for deeply nested enumerated lists.
+    Creates the proper docutils node based on the sub-type
+    of the underlying data object. Takes care of proper numbering
+    for deeply nested enumerated lists.
     """
 
     numeral_kind = ['arabic', 'loweralpha', 'lowerroman', 'upperalpha', 'upperroman']
@@ -966,10 +966,10 @@ class DocListNestedRenderer(object):
 
 
 class DocListTypeSubRenderer(Renderer):
-    """
-        List renderer.
-        The specifics of the actual list rendering are handled by the
-        decorator around the generic render function.
+    """List renderer
+
+    The specifics of the actual list rendering are handled by the
+    decorator around the generic render function.
     """
 
     @DocListNestedRenderer
@@ -985,8 +985,7 @@ class DocListTypeSubRenderer(Renderer):
 
 
 class DocListItemTypeSubRenderer(Renderer):
-    """
-        List item renderer.
+    """List item renderer.
     """
 
     def render(self):
@@ -1000,3 +999,22 @@ class DocListItemTypeSubRenderer(Renderer):
             nodelist.extend(renderer.render())
 
         return [self.node_factory.list_item("", *nodelist)]
+
+
+class DocHeadingTypeSubRenderer(Renderer):
+    """Heading renderer.
+
+    Renders embedded headlines as emphasized text. Different heading levels
+    are not supported.
+    """
+
+    def render(self):
+
+        nodelist = []
+        for item in self.data_object.content_:
+            context = self.context.create_child_context(item)
+            renderer = self.renderer_factory.create_renderer(context)
+            nodelist.extend(renderer.render())
+
+        return [self.node_factory.emphasis("", "", *nodelist)]
+
